@@ -3,7 +3,7 @@ model_parameters.bfsl <- function(model,
                                   ci = 0.95,
                                   ci_method = "residual",
                                   p_adjust = NULL,
-                                  summary = getOption("parameters_summary", FALSE),
+                                  include_info = getOption("parameters_info", FALSE),
                                   keep = NULL,
                                   drop = NULL,
                                   verbose = TRUE,
@@ -16,7 +16,7 @@ model_parameters.bfsl <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     ...
   )
 
@@ -37,20 +37,3 @@ standard_error.bfsl <- function(model, ...) {
   )
   insight::text_remove_backticks(params, verbose = FALSE)
 }
-
-
-
-#' @export
-degrees_of_freedom.bfsl <- function(model, method = "residual", ...) {
-  if (is.null(method)) {
-    method <- "wald"
-  }
-
-  method <- match.arg(tolower(method), choices = c("analytical", "any", "fit", "wald", "residual", "normal"))
-
-  if (method %in% c("wald", "residual", "fit")) {
-    model$df.residual
-  } else {
-    degrees_of_freedom.default(model, method = method, ...)
-  }
-}
