@@ -5,7 +5,6 @@
 ############# .bracl --------------
 
 
-#' @rdname model_parameters.mlm
 #' @export
 model_parameters.bracl <- function(model,
                                    ci = 0.95,
@@ -14,7 +13,7 @@ model_parameters.bracl <- function(model,
                                    standardize = NULL,
                                    exponentiate = FALSE,
                                    p_adjust = NULL,
-                                   summary = getOption("parameters_summary", FALSE),
+                                   include_info = getOption("parameters_info", FALSE),
                                    keep = NULL,
                                    drop = NULL,
                                    verbose = TRUE,
@@ -56,7 +55,7 @@ model_parameters.bracl <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     vcov = NULL,
     vcov_args = NULL
   )
@@ -138,8 +137,6 @@ p_value.bracl <- function(model, verbose = TRUE, ...) {
 }
 
 
-
-
 ############# .multinom --------------
 
 
@@ -152,7 +149,7 @@ model_parameters.multinom <- function(model,
                                       standardize = NULL,
                                       exponentiate = FALSE,
                                       p_adjust = NULL,
-                                      summary = getOption("parameters_summary", FALSE),
+                                      include_info = getOption("parameters_info", FALSE),
                                       keep = NULL,
                                       drop = NULL,
                                       verbose = TRUE,
@@ -166,7 +163,7 @@ model_parameters.multinom <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
-    summary = summary,
+    include_info = include_info,
     keep = keep,
     drop = drop,
     verbose = verbose,
@@ -181,19 +178,6 @@ ci.multinom <- function(x, ci = 0.95, method = "normal", verbose = TRUE, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.multinom <- function(model, method = NULL, ...) {
-  if (is.null(method) || identical(method, "normal")) {
-    Inf
-  } else {
-    insight::n_obs(model) - model$edf
-  }
-}
-
-#' @export
-degrees_of_freedom.nnet <- degrees_of_freedom.multinom
-
-
 #' @export
 standard_error.multinom <- function(model, ...) {
   se <- tryCatch(
@@ -284,8 +268,6 @@ simulate_parameters.multinom <- function(model,
 }
 
 
-
-
 ############# .brmultinom --------------
 
 
