@@ -2,22 +2,17 @@
 
 # .lm ---------------------
 
-#' @export
-standard_error.lm <- standard_error.glm
-
 
 #' @export
 p_value.lm <- p_value.default
 
 
 #' @export
-ci.lm <- function(x, ci = .95, method = "residual", robust = FALSE, ...) {
-  .ci_generic(model = x, ci = ci, method = method, robust = robust, ...)
+ci.lm <- function(x, ci = 0.95, method = "residual", ...) {
+  .ci_generic(model = x, ci = ci, method = method, ...)
 }
 
 
-
-
 # .summary.lm ---------------------
 
 #' @export
@@ -47,12 +42,6 @@ p_value.summary.lm <- function(model, ...) {
 
 
 #' @export
-ci.summary.lm <- function(x, ci = .95, method = "residual", ...) {
-  .ci_generic(model = x, ci = ci, method = method, dof = degrees_of_freedom(x), ...)
-}
-
-
-#' @export
-degrees_of_freedom.summary.lm <- function(model, ...) {
-  model$fstatistic[3]
+ci.summary.lm <- function(x, ci = 0.95, method = "residual", ...) {
+  .ci_generic(model = x, ci = ci, method = method, dof = insight::get_df(x), ...)
 }
