@@ -1,18 +1,14 @@
+## from rms / rmsb package
 
-#' @export
-ci.lrm <- ci.tobit
+
+# model parameters -------------
 
 
 #' @export
-ci.psm <- ci.tobit
+model_parameters.blrm <- model_parameters.bayesQR
 
 
-#' @export
-ci.ols <- ci.tobit
-
-
-#' @export
-ci.rms <- ci.tobit
+# standard error -------------
 
 
 #' @export
@@ -28,23 +24,32 @@ standard_error.lrm <- function(model, ...) {
   )
 }
 
-
 #' @export
 standard_error.ols <- standard_error.lrm
 
-
 #' @export
 standard_error.rms <- standard_error.lrm
 
-
 #' @export
 standard_error.psm <- standard_error.lrm
 
 
+# p-values -----------------------
+
 #' @export
 p_value.lrm <- function(model, ...) {
   stat <- insight::get_statistic(model)
-  p <- 2 * stats::pt(abs(stat$Statistic), df = degrees_of_freedom(model, method = "any"), lower.tail = FALSE)
+
+  # Issue: 697: typically the degrees of freedom are the same for every
+  # observation, but the value is repeated. This poses problems in multiple
+  # imputation models with Hmisc when we get more df values than parameters.
+  dof <- insight::get_df(model, type = "wald")
+  dfu <- unique(dof)
+  if (length(dfu) == 1) {
+    dof <- dfu
+  }
+
+  p <- 2 * stats::pt(abs(stat$Statistic), df = dof, lower.tail = FALSE)
 
   .data_frame(
     Parameter = .remove_backticks_from_string(stat$Parameter),
@@ -52,15 +57,14 @@ p_value.lrm <- function(model, ...) {
   )
 }
 
-
 #' @export
 p_value.ols <- p_value.lrm
 
-
 #' @export
 p_value.rms <- p_value.lrm
 
-
 #' @export
 p_value.psm <- p_value.lrm
 
+#' @export
+p_value.blrm <- p_value.BFBayesFactor
