@@ -8,9 +8,10 @@
 #'
 #' Extract and compute indices and measures to describe parameters of meta-analysis models.
 #'
-#' @param include_studies Logical, if `TRUE` (default), includes parameters
-#'   for all studies. Else, only parameters for overall-effects are shown.
+#' @param include_studies Logical, if `TRUE` (default), includes parameters for
+#' all studies. Else, only parameters for overall-effects are shown.
 #' @inheritParams model_parameters.default
+#' @inheritParams model_parameters.glimML
 #'
 #' @examples
 #' library(parameters)
@@ -22,7 +23,7 @@
 #'   model <- rma(yi = effectsize, sei = stderr, method = "REML", data = mydat)
 #'   model_parameters(model)
 #' }
-#' \dontrun{
+#' \donttest{
 #' # with subgroups
 #' if (require("metafor", quietly = TRUE)) {
 #'   data(dat.bcg)
@@ -35,13 +36,14 @@
 #'     data = dat.bcg
 #'   )
 #'   dat$alloc <- ifelse(dat$alloc == "random", "random", "other")
-#'   model <- rma(yi, vi, mods = ~alloc, data = dat, digits = 3, slab = author)
+#'   d <<- dat
+#'   model <- rma(yi, vi, mods = ~alloc, data = d, digits = 3, slab = author)
 #'   model_parameters(model)
 #' }
 #'
 #' if (require("metaBMA", quietly = TRUE)) {
 #'   data(towels)
-#'   m <- meta_random(logOR, SE, study, data = towels)
+#'   m <- suppressWarnings(meta_random(logOR, SE, study, data = towels))
 #'   model_parameters(m)
 #' }
 #' }
@@ -49,20 +51,30 @@
 #' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.rma <- function(model,
-                                 ci = .95,
+                                 ci = 0.95,
                                  bootstrap = FALSE,
                                  iterations = 1000,
                                  standardize = NULL,
                                  exponentiate = FALSE,
                                  include_studies = TRUE,
+                                 keep = NULL,
+                                 drop = NULL,
                                  verbose = TRUE,
                                  ...) {
   # handle ci-level that was defined in function call...
-  ci_level <- parse(text = .safe_deparse(model$call))[[1]]$level
+  ci_level <- parse(text = insight::safe_deparse(model$call))[[1]]$level
   if (!is.null(ci_level) && missing(ci)) {
     ci <- ci_level / 100
   }
 
+  # validation check, warn if unsupported argument is used.
+  .check_dots(
+    dots = list(...),
+    not_allowed = c("vcov", "vcov_args"),
+    class(model)[1],
+    verbose = verbose
+  )
+
   meta_analysis_overall <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -71,6 +83,9 @@ model_parameters.rma <- function(model,
     merge_by = "Parameter",
     standardize = standardize,
     exponentiate = exponentiate,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    verbose = verbose,
     ...
   )
 
@@ -80,7 +95,7 @@ model_parameters.rma <- function(model,
   # subgroup analyses?
   if (!is.null(model$formula.mods)) {
     group_variable <- deparse(model$formula.mods[[2]])[1]
-    model_data <- insight::get_data(model)
+    model_data <- insight::get_data(model, verbose = FALSE)
     if (group_variable %in% colnames(model_data)) {
       subgroups <- sort(unique(model_data[[group_variable]]))
     }
@@ -142,13 +157,13 @@ model_parameters.rma <- function(model,
   }
 
   original_attributes$names <- names(out)
-  original_attributes$row.names <- 1:nrow(out)
+  original_attributes$row.names <- seq_len(nrow(out))
   original_attributes$pretty_names <- stats::setNames(out$Parameter, out$Parameter)
   attributes(out) <- original_attributes
 
   # no df
   out$df_error <- NULL
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   attr(out, "measure") <- model$measure
 
   if (!"Method" %in% names(out)) {
@@ -172,7 +187,7 @@ p_value.rma <- function(model, ...) {
 
 
 #' @export
-ci.rma <- function(x, ci = .95, ...) {
+ci.rma <- function(x, ci = 0.95, ...) {
   params <- insight::get_parameters(x)
   out <- tryCatch(
     {
@@ -185,7 +200,7 @@ ci.rma <- function(x, ci = .95, ...) {
           CI_high = as.vector(model$ci.ub)
         )
       })
-      .remove_backticks_from_parameter_names(do.call(rbind, tmp))
+      insight::text_remove_backticks(do.call(rbind, tmp), verbose = FALSE)
     },
     error = function(e) {
       NULL
@@ -203,7 +218,7 @@ ci.rma <- function(x, ci = .95, ...) {
         CI_high = params$Estimate + as.vector(se$SE) * fac
       )
     })
-    out <- .remove_backticks_from_parameter_names(do.call(rbind, out))
+    out <- insight::text_remove_backticks(do.call(rbind, out), verbose = FALSE)
   }
   out
 }
