@@ -2,8 +2,8 @@
 #'
 #' Parameters from Hypothesis Testing.
 #'
-#' @param model Object of class [multcomp::glht()] (\pkg{multcomp})
-#'   or of class `PMCMR`, `trendPMCMR` or `osrt` (\pkg{PMCMRplus}).
+#' @param model Object of class [multcomp::glht()] (**multcomp**)
+#'   or of class `PMCMR`, `trendPMCMR` or `osrt` (**PMCMRplus**).
 #' @inheritParams model_parameters.default
 #'
 #' @return A data frame of indices related to the model's parameters.
@@ -26,17 +26,20 @@
 #'   model_parameters(mod)
 #' }
 #' if (require("PMCMRplus", quietly = TRUE)) {
-#'   model <- kwAllPairsConoverTest(count ~ spray, data = InsectSprays)
+#'   model <- suppressWarnings(
+#'     kwAllPairsConoverTest(count ~ spray, data = InsectSprays)
+#'   )
 #'   model_parameters(model)
 #' }
 #' }
 #' @export
 model_parameters.glht <- function(model,
-                                  ci = .95,
+                                  ci = 0.95,
                                   exponentiate = FALSE,
+                                  keep = NULL,
+                                  drop = NULL,
                                   verbose = TRUE,
                                   ...) {
-
   # p-adjustment method
   s <- summary(model)
   p_adjust <- s$test$type
@@ -49,20 +52,31 @@ model_parameters.glht <- function(model,
     merge_by = "Parameter",
     standardize = NULL,
     exponentiate = exponentiate,
-    robust = FALSE,
     p_adjust = NULL,
+    keep_parameters = keep,
+    drop_parameters = drop,
     verbose = verbose,
     ...
   )
 
   attr(out, "p_adjust") <- p_adjust
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
 
 #' @export
-ci.glht <- function(x, ci = .95, robust = TRUE, ...) {
+ci.glht <- function(x, ci = 0.95, ...) {
+  # backward compatibility with `robust` argument
+  dots <- list(...)
+  if ("robust" %in% names(dots) && !"vcov" %in% names(dots)) {
+    robust <- dots[["robust"]]
+  } else if (any(c("vcov", "vcov_args") %in% names(dots))) {
+    robust <- TRUE
+  } else {
+    robust <- FALSE
+  }
+
   s <- summary(x)
   if (robust) {
     adjusted_ci <- 2 * stats::pnorm(s$test$qfunction(ci)) - 1
@@ -89,12 +103,6 @@ standard_error.glht <- function(model, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.glht <- function(model, ...) {
-  model$df
-}
-
-
 #' @export
 p_value.glht <- function(model, ...) {
   s <- summary(model)
