@@ -8,52 +8,73 @@ model_parameters.zeroinfl <- model_parameters.zcpglm
 #' @export
 model_parameters.hurdle <- model_parameters.zcpglm
 
-
 #' @export
 model_parameters.zerocount <- model_parameters.zcpglm
 
 
-
-
 # ci -----------------
 
 #' @export
-ci.zeroinfl <- ci.glmmTMB
+ci.zeroinfl <- function(x,
+                        ci = 0.95,
+                        dof = NULL,
+                        method = "wald",
+                        component = "all",
+                        verbose = TRUE,
+                        ...) {
+  method <- tolower(method)
+  method <- insight::validate_argument(
+    method,
+    c("wald", "normal", "residual", "robust")
+  )
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated")
+  )
 
+  if (is.null(.check_component(x, component, verbose = verbose))) {
+    return(NULL)
+  }
+
+  # all other
+  .ci_generic(model = x, ci = ci, dof = dof, method = method, component = component, ...)
+}
 
 #' @export
-ci.hurdle <- ci.glmmTMB
-
+ci.hurdle <- ci.zeroinfl
 
 #' @export
-ci.zerocount <- ci.glmmTMB
-
-
+ci.zerocount <- ci.zeroinfl
 
 
 # standard error -----------------
 
-
-#' @rdname standard_error
 #' @export
 standard_error.zeroinfl <- function(model,
-                                    component = c("all", "conditional", "zi", "zero_inflated"),
+                                    component = "all",
                                     method = NULL,
                                     verbose = TRUE,
                                     ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated")
+  )
   if (is.null(.check_component(model, component, verbose = verbose))) {
     return(NULL)
   }
 
   robust <- !is.null(method) && method == "robust"
-  if (isTRUE(robust)) {
-    return(standard_error_robust(model, ...))
+  if (.check_vcov_args(robust, ...)) {
+    return(standard_error.default(model, component = component, ...))
   }
 
-  cs <- .compact_list(stats::coef(summary(model)))
+  cs <- insight::compact_list(stats::coef(summary(model)))
   x <- lapply(names(cs), function(i) {
-    comp <- ifelse(i == "count", "conditional", "zi")
+    if (i == "count") {
+      comp <- "conditional"
+    } else {
+      comp <- "zi"
+    }
 
     stats <- cs[[i]]
 
@@ -77,36 +98,37 @@ standard_error.zeroinfl <- function(model,
   .filter_component(se, component)
 }
 
-
 #' @export
 standard_error.hurdle <- standard_error.zeroinfl
 
-
 #' @export
 standard_error.zerocount <- standard_error.zeroinfl
 
 
-
-
 # p values -----------------------
 
-
-#' @rdname p_value.zcpglm
 #' @export
-p_value.zeroinfl <- function(model, component = c("all", "conditional", "zi", "zero_inflated"), method = NULL, verbose = TRUE, ...) {
-  component <- match.arg(component)
+p_value.zeroinfl <- function(model, component = "all", method = NULL, verbose = TRUE, ...) {
+  component <- insight::validate_argument(
+    component,
+    c("all", "conditional", "zi", "zero_inflated")
+  )
   if (is.null(.check_component(model, component, verbose = verbose))) {
     return(NULL)
   }
 
   robust <- !is.null(method) && method == "robust"
-  if (isTRUE(robust)) {
-    return(p_value_robust(model, ...))
+  if (.check_vcov_args(robust, ...)) {
+    return(p_value.default(model, component = component, ...))
   }
 
-  cs <- .compact_list(stats::coef(summary(model)))
+  cs <- insight::compact_list(stats::coef(summary(model)))
   x <- lapply(names(cs), function(i) {
-    comp <- ifelse(i == "count", "conditional", "zi")
+    if (i == "count") {
+      comp <- "conditional"
+    } else {
+      comp <- "zi"
+    }
     stats <- cs[[i]]
 
     # remove log(theta)
@@ -129,20 +151,15 @@ p_value.zeroinfl <- function(model, component = c("all", "conditional", "zi", "z
   .filter_component(p, component)
 }
 
-
 #' @export
 p_value.hurdle <- p_value.zeroinfl
 
-
 #' @export
 p_value.zerocount <- p_value.zeroinfl
 
 
-
-
 # simulate model -----------------
 
-
 #' @export
 simulate_model.zeroinfl <- simulate_model.glmmTMB
 
@@ -153,15 +170,13 @@ simulate_model.hurdle <- simulate_model.zeroinfl
 simulate_model.zerocount <- simulate_model.zeroinfl
 
 
-
-
 # simulate paramaters -----------------
 
 #' @export
 simulate_parameters.zeroinfl <- function(model,
                                          iterations = 1000,
                                          centrality = "median",
-                                         ci = .95,
+                                         ci = 0.95,
                                          ci_method = "quantile",
                                          test = "p-value",
                                          ...) {
@@ -177,11 +192,11 @@ simulate_parameters.zeroinfl <- function(model,
     )
 
   params <- insight::get_parameters(model)
-  if ("Effects" %in% colnames(params) && .n_unique(params$Effects) > 1) {
+  if ("Effects" %in% colnames(params) && insight::n_unique(params$Effects) > 1) {
     out$Effects <- params$Effects
   }
 
-  if ("Component" %in% colnames(params) && .n_unique(params$Component) > 1) {
+  if ("Component" %in% colnames(params) && insight::n_unique(params$Component) > 1) {
     out$Component <- params$Component
   }
 
@@ -190,17 +205,17 @@ simulate_parameters.zeroinfl <- function(model,
   }
 
   class(out) <- c("parameters_simulate", "see_parameters_simulate", class(out))
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   attr(out, "iterations") <- iterations
   attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
+  attr(out, "centrality") <- centrality
 
   out
 }
 
-
 #' @export
 simulate_parameters.hurdle <- simulate_parameters.zeroinfl
 
-
 #' @export
 simulate_parameters.zerocount <- simulate_parameters.zeroinfl
