@@ -41,14 +41,14 @@
 #' @param hclust_method The hierarchical clustering method (passed to [`hclust()`]).
 #' @param nbclust_method The clustering method (passed to `NbClust::NbClust()`
 #'   as `method`).
-#' @inheritParams model_parameters.glm
+#' @inheritParams model_parameters.default
 #'
 #'
 #'
 #' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html) implemented in the [**see**-package](https://easystats.github.io/see/).
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' library(parameters)
 #'
 #' # The main 'n_clusters' function ===============================
@@ -111,7 +111,7 @@ n_clusters <- function(x,
   out$Method <- as.character(out$Method)
 
   # Remove duplicate methods starting with the smallest
-  dupli <- c()
+  dupli <- NULL
   for (i in seq_len(nrow(out))) {
     if (i > 1 && out[i, "Method"] %in% out$Method[1:i - 1]) {
       dupli <- c(dupli, i)
@@ -130,7 +130,7 @@ n_clusters <- function(x,
 
   attr(out, "summary") <- by_clusters
   attr(out, "n") <- min(as.numeric(as.character(
-    by_clusters[by_clusters$n_Methods == max(by_clusters$n_Methods), c("n_Clusters")]
+    by_clusters[by_clusters$n_Methods == max(by_clusters$n_Methods), "n_Clusters"]
   )))
 
   class(out) <- c("n_clusters", "see_n_clusters", class(out))
@@ -138,8 +138,6 @@ n_clusters <- function(x,
 }
 
 
-
-
 #' @keywords internal
 .n_clusters_mclust <- function(x, n_max = 10, ...) {
   insight::check_if_installed("mclust")
@@ -152,7 +150,7 @@ n_clusters <- function(x,
   models <- as.character(sapply(out, function(x) x[[1]]))
   n <- as.numeric(sapply(out, function(x) x[[2]]))
 
-  data.frame(
+  .data_frame(
     n_Clusters = n,
     Method = paste0("Mixture (", models, ")"),
     Package = "mclust",
@@ -161,8 +159,6 @@ n_clusters <- function(x,
 }
 
 
-
-
 # Methods -----------------------------------------------------------------
 
 
@@ -173,7 +169,7 @@ n_clusters <- function(x,
   gap1 <- n_clusters_gap(x, preprocess = FALSE, gap_method = "firstSEmax", n_max = n_max, ...)
   gap2 <- n_clusters_gap(x, preprocess = FALSE, gap_method = "globalSEmax", n_max = n_max, ...)
 
-  data.frame(
+  .data_frame(
     n_Clusters = c(
       attributes(elb)$n,
       attributes(sil)$n,
@@ -192,8 +188,6 @@ n_clusters <- function(x,
 }
 
 
-
-
 #' @keywords internal
 .n_clusters_NbClust <- function(x, fast = TRUE, nbclust_method = "kmeans", n_max = 10, indices = "all", ...) {
   insight::check_if_installed("NbClust")
@@ -235,12 +229,12 @@ n_clusters <- function(x,
       w <- ""
       if (!is.null(n$warnings)) {
         w <- paste0("\n  - ", unlist(n$warnings), collapse = "")
-        warning(paste0("For ", idx, " index (NbClust):", w), call. = FALSE)
+        insight::format_warning(paste0("For ", idx, " index (NbClust):", w))
       }
 
       # Don't merge results if convergence issue
-      if (grepl("did not converge in", w) == FALSE) {
-        out <- rbind(out, data.frame(
+      if (!grepl("did not converge in", w, fixed = TRUE)) {
+        out <- rbind(out, .data_frame(
           n_Clusters = n$out$Best.nc[["Number_clusters"]],
           Method = idx,
           Package = "NbClust",
@@ -255,7 +249,7 @@ n_clusters <- function(x,
 
 #' @keywords internal
 .n_clusters_M3C <- function(x, n_max = 10, fast = TRUE, ...) {
-  if (!requireNamespace("M3C", quietly = TRUE)) {
+  if (!requireNamespace("M3C", quietly = TRUE)) { # nolint
     insight::format_error(
       "Package `M3C` required for this function to work. Please install it by first running `remotes::install_github('https://github.com/crj32/M3C')` (the package is not on CRAN)."
     ) # Not on CRAN (but on github and bioconductor)
@@ -267,7 +261,7 @@ n_clusters <- function(x,
   t0 <- Sys.time()
   out <- M3C::M3C(data, method = 2, maxK = n_max, removeplots = TRUE, silent = TRUE)
 
-  out <- data.frame(
+  out <- .data_frame(
     n_Clusters = out$scores[which.min(out$scores$PCSI), "K"],
     Method = "Consensus clustering algorithm (penalty term)",
     Package = "M3C",
@@ -275,12 +269,12 @@ n_clusters <- function(x,
   )
 
   # Monte Carlo Version (Super slow)
-  if (fast == FALSE) {
+  if (isFALSE(fast)) {
     t0 <- Sys.time()
     out2 <- M3C::M3C(data, method = 1, maxK = n_max, removeplots = TRUE, silent = TRUE)
     out <- rbind(
       out,
-      data.frame(
+      .data_frame(
         n_Clusters = out2$scores[which.max(out2$scores$RCSI), "K"],
         Method = "Consensus clustering algorithm (Monte Carlo)",
         Package = "M3C",
