@@ -17,7 +17,7 @@
 #'
 #' @family standardize
 #'
-#' @examplesIf insight::check_if_installed("datawizard", minimum_version = "0.12.0", quietly = TRUE)
+#' @examplesIf insight::check_if_installed("datawizard", quietly = TRUE)
 #' model <- lm(mpg ~ ., data = mtcars)
 #' standardize_info(model)
 #' standardize_info(model, robust = TRUE)
@@ -50,7 +50,6 @@ standardize_info.default <- function(model,
     insight::find_parameters(model, effects = "fixed", flatten = TRUE, ...)
   }
   types <- parameters_type(model)
-  # model_matrix <- as.data.frame(stats::model.matrix(model))
   model_matrix <- as.data.frame(insight::get_modelmatrix(model))
   model_data <- insight::get_data(model, source = "mf", verbose = FALSE)
   wgts <- insight::get_weights(model, remove_na = TRUE)
@@ -323,9 +322,12 @@ standardize_info.default <- function(model,
   if (info$is_linear) {
     if (inherits(model, c("gls", "lme"))) {
       response <- insight::get_response(model)
+    } else if (inherits(model, "fixest")) {
+      response <- stats::model.matrix(model, type = "lhs")
     } else {
       response <- stats::model.frame(model)[[1]]
     }
+
     means <- deviations <- rep(NA_real_, length = length(names(model_matrix)))
     for (i in seq_along(names(model_matrix))) {
       variable <- names(model_matrix)[i]
@@ -367,6 +369,8 @@ standardize_info.default <- function(model,
 .std_info_response_basic <- function(model, info, params, robust = FALSE, w = NULL, ...) {
   if (inherits(model, c("gls", "lme"))) {
     response <- insight::get_response(model)
+  } else if (inherits(model, "fixest")) {
+    response <- stats::model.matrix(model, type = "lhs")
   } else {
     response <- stats::model.frame(model)[[1]]
   }
@@ -411,11 +415,12 @@ standardize_info.default <- function(model,
   }
 
   insight::check_if_installed("performance")
-  insight::check_if_installed("datawizard", minimum_version = "0.12.0")
+  insight::check_if_installed("datawizard")
 
   f <- if (two_sd) 2 else 1
 
-  within_vars <- unclass(performance::check_heterogeneity_bias(model))
+  gv <- performance::check_group_variation(model)
+  within_vars <- gv[gv$Variation %in% c("both", "within"), "Variable"]
   id <- insight::get_random(model)[[1]]
   w <- insight::get_weights(model, remove_na = TRUE)
 
