@@ -64,7 +64,7 @@
 #' delta.
 #' - **pseudo** (*for 2-level (G)LMMs only*): In this (post-hoc) method, the
 #' response and the predictor are standardized based on the level of prediction
-#' (levels are detected with [`performance::check_heterogeneity_bias()`]): Predictors
+#' (levels are detected with [`performance::check_group_variation()`]): Predictors
 #' are standardized based on their SD at level of prediction (see also
 #' [`datawizard::demean()`]); The outcome (in linear LMMs) is standardized based
 #' on a fitted random-intercept-model, where `sqrt(random-intercept-variance)`
@@ -519,6 +519,23 @@ format.parameters_standardized <- function(x,
 }
 
 
+#' @export
+display.parameters_standardized <- function(object,
+                                            format = "markdown",
+                                            digits = 2,
+                                            ...) {
+  format <- .display_default_format(format)
+  fun_args <- list(x = object, digits = digits)
+
+  if (format %in% c("html", "tt")) {
+    fun_args$backend <- format
+    do.call(print_html, c(fun_args, list(...)))
+  } else {
+    do.call(print_md, c(fun_args, list(...)))
+  }
+}
+
+
 #' @export
 print.parameters_standardized <- function(x, digits = 2, ...) {
   x_fmt <- format(x, digits = digits, output = "text", ...)
@@ -534,8 +551,11 @@ print_md.parameters_standardized <- function(x, digits = 2, ...) {
 
 #' @export
 print_html.parameters_standardized <- function(x, digits = 2, ...) {
+  # which engine?
+  engine <- .check_format_backend(...)
+
   x_fmt <- format(x, digits = digits, output = "html", ...)
-  insight::export_table(x_fmt, format = "html", ...)
+  insight::export_table(x_fmt, format = engine, ...)
 }
 
 
