@@ -1,9 +1,8 @@
 skip_on_os("mac")
-
 skip_on_cran()
+skip_if_not_installed("rstanarm")
 
 test_that("mp", {
-  skip_if_not_installed("rstanarm")
   set.seed(123)
   model <- rstanarm::stan_glm(
     vs ~ mpg + cyl,
@@ -21,7 +20,6 @@ test_that("mp", {
 
 
 test_that("mp2", {
-  skip_if_not_installed("rstanarm")
   data(pbcLong, package = "rstanarm")
   pbcLong$ybern <- as.integer(pbcLong$logBili >= mean(pbcLong$logBili))
   set.seed(123)
@@ -48,3 +46,16 @@ test_that("mp2", {
   expect_identical(mp$Response, c("y1", "y1", "y2", "y2", "y2"))
   expect_equal(mp$Prior_Scale, c(4.9647, 0.3465, 5.57448, 1.39362, 0.38906), tolerance = 1e-2)
 })
+
+
+test_that("mp3", {
+  skip_if_not_installed("curl")
+  skip_if_offline()
+  skip_if_not_installed("httr2")
+  m <- insight::download_model("stanreg_merMod_1")
+  skip_if(is.null(m))
+  out <- model_parameters(m, effects = "grouplevel")
+  expect_identical(dim(out), c(3L, 9L))
+  expect_equal(out$Median, c(0.21861, 0.17629, -0.68358), tolerance = 1e-3)
+  expect_identical(out$Parameter, c("b[(Intercept) gear:3]", "b[(Intercept) gear:4]", "b[(Intercept) gear:5]"))
+})
