@@ -1,7 +1,7 @@
 skip_on_os("mac")
 skip_if_not_installed("WeightIt", minimum_version = "1.2.0")
 skip_if_not_installed("cobalt")
-skip_if_not_installed("insight", minimum_version = "0.20.4")
+skip_if_not_installed("insight")
 
 test_that("weightit, multinom", {
   data("lalonde", package = "cobalt")
